@@ -25,7 +25,7 @@ pub mod player_list;
 pub mod q3_error;
 pub mod server_info;
 
-use std::net;
+use std::net::{self, UdpSocket};
 
 use q3_error::Q3Error;
 use server_info::ServerInfo;
@@ -44,9 +44,15 @@ impl Q3Tool {
         }
     }
 
+    pub fn new_with_rcon(host: &str, password: &str) -> Self {
+        Self {
+            host: host.to_owned(),
+            password: Some(password.to_owned()),
+        }
+    }
+
     pub fn get_status(&self) -> Result<ServerInfo, Q3Error> {
-        let socket = net::UdpSocket::bind("0.0.0.0:0")?;
-        socket.connect(&self.host)?;
+        let socket = self.get_socket()?;
 
         let mut buffer = [0; 2048];
 
@@ -56,7 +62,33 @@ impl Q3Tool {
         let raw_info = String::from_utf8_lossy(&buffer);
         let (_header, raw_info) = raw_info.split_once("\n").unwrap();
 
-        Ok(ServerInfo::new(raw_info)?)
+        let server_info = ServerInfo::new(raw_info)?;
+
+        Ok(server_info)
+    }
+
+    pub fn send_rcon(&self, command: &str) -> Result<String, Q3Error> {
+        let password = match &self.password {
+            Some(password) => password,
+            None => return Err(Q3Error::UserError),
+        };
+
+        let socket = self.get_socket()?;
+
+        let mut buffer = [0; 2048];
+        let prefix = b"\xFF\xFF\xFF\xFFrcon ";
+        let suffix = format!("{} {}", &password, &command);
+
+        socket.send(&[prefix, suffix.as_bytes()].concat()[..])?;
+        socket.recv(&mut buffer)?;
+
+        Ok(String::from_utf8_lossy(&buffer).to_string())
+    }
+
+    fn get_socket(&self) -> Result<UdpSocket, Q3Error> {
+        let socket = net::UdpSocket::bind("0.0.0.0:0")?;
+        socket.connect(&self.host)?;
+        Ok(socket)
     }
 }
 
